
# THIS FILE IS GENERATED FROM NUMPY SETUP.PY
#
# To compare versions robustly, use `numpy.lib.NumpyVersion`
short_version = '1.14.4'
version = '1.14.4'
full_version = '1.14.4'
git_revision = '4585a85010c87a861192d67e04f6d534fb3be2fc'
release = True

if not release:
    version = full_version
